# `relationalai.Producer.__rpow__()`

```python
relationalai.Producer.__rpow__(base: Any) -> Expression
```

Returns an [`Expression`](../Expression.md) that produces the power of `base` raised to the values produced by the [`Producer`](./README.md).
`.__rpow__()` is implemented so that you may use a non-`Producer` object as the base of the exponent.

#### See Also

[`Producer.__pow__()`](./pow__.md)
